output "runtime_url" {
  value       = google_cloud_run_v2_service.runtime.uri
  description = "Astromesh runtime URL"
}

output "db_connection_name" {
  value       = google_sql_database_instance.main.connection_name
  description = "Cloud SQL connection name"
}

output "redis_host" {
  value       = google_redis_instance.main.host
  description = "Memorystore Redis host"
}
