@import "tailwindcss";

@keyframes slide-in {
  from {
    opacity: 0;
    transform: translateX(100%);
  }
  to {
    opacity: 1;
    transform: translateX(0);
  }
}

@utility animate-slide-in {
  animation: slide-in 0.2s ease-out;
}
