resource "google_vpc_access_connector" "orbit" {
  name          = "{{ meta.name }}-vpc"
  project       = var.project_id
  region        = var.region
  ip_cidr_range = "10.8.0.0/28"
  network       = "default"
}
